Learn R Programming

dtGAP (version 0.0.2)

col_ht: Create Column Heatmap with Variable Importance

Description

Constructs a ComplexHeatmap object displaying feature-feature correlations with optional variable importance barplots and split-variable highlighting.

Usage

col_ht(
  fit,
  sorted_dat,
  var_imp,
  layout,
  include_var_imp = TRUE,
  col_var_imp = "orange",
  var_bar_width = 0.8,
  var_fontsize = 5,
  split_var_bg = "darkgreen",
  split_var_fontsize = 5,
  palette = "RdBu",
  n_colors = 11,
  show_col_prox = TRUE
)

Value

A Heatmap object from ComplexHeatmap.

Arguments

fit

A fitted partykit tree object used to extract split variables.

sorted_dat

List from sorted_mat()

var_imp

Named numeric vector of variable importance scores.

layout

List with layout dimensions

include_var_imp

Logical; include importance barplot if TRUE (default TRUE).

col_var_imp

Color for importance bars (default "orange").

var_bar_width

Numeric width of bars (default 0.8).

var_fontsize

Font size for importance text (default 5).

split_var_bg

Background color for split variable names (default "darkgreen").

split_var_fontsize

Font size for split variable names (default 5).

palette

RColorBrewer palette for correlation heatmap (default "RdBu").

n_colors

Number of colors in correlation scale (default 11).

show_col_prox

Logical, whether to show column proximity.