Combines sorted data matrix and provided annotations into a single Heatmap.
make_main_heatmap(
sorted_dat,
split_vec,
pred_ha,
row_prop_ha,
layout,
palette = "Blues",
n_colors = 9,
show_row_names = TRUE,
row_names_gp = gpar(fontsize = 5),
show_row_prox = TRUE,
raw_value_col = NULL
)A configured Heatmap object.
List from sorted_mat(), containing sorted_test_matrix.
Factor defining row splits in the heatmap.
A rowAnnotation for predictions (from prediction_annotation).
A rowAnnotation for row proximity (from row_prop_anno).
List with row_h and col_h in mm.
RColorBrewer palette for heatmap values (default "Blues").
Number of colors for heatmap (default 9).
Logical. Whether to display row names in the heatmap (default TRUE).
gpar settings for row name font (default fontsize=5).
Logical, whether to show the right annotation for row proximity.
User-defined colors for raw data values.