Creates a ComplexHeatmap row annotation showing supervised proximity for each data sample, grouped by a split vector.
row_prop_anno(
sorted_dat,
layout,
split_vec,
palette = "Spectral",
n_colors = 11,
border = TRUE,
gap_mm = unit(1, "mm"),
show_row_prox = TRUE
)A rowAnnotation object for use in a ComplexHeatmap.
List from sorted_mat()
List with layout dimensions
Factor dividing columns of the proximity matrix into groups.
RColorBrewer palette name for color scale (default "OrRd").
Number of discrete colors to generate (default 9).
Logical; draw cell borders if TRUE (default TRUE).
Unit object for gap between annotation blocks (default unit(1, "mm") ).
Logical, whether to show row proximity.